@@ -29,23 +29,13 @@ class Barry:
         return (t.replace(second=0, microsecond=0, minute=0, hour=t.hour)
                 + timedelta(hours=t.minute // 30))
 
-    def get_currency(self, price_code):
-        headers = {
-            'Authorization': 'Bearer ' + self.access_token,
-            'Content-Type': 'application/json',
-        }
-        data = '{ "jsonrpc": "2.0", "id": 0, "method": "co.getbarry.api.v1.OpenApiController.getPriceDefinitions", "params": [] }'
-        response = requests.post('https://jsonrpc.barry.energy/json-rpc', headers=headers, data=data)
-        json_res = response.json()
-        result = json_res.get('result')
-        if result:
-            for data in result:
-                if data['priceCode'] == price_code:
-                    if data['country'] == 'DK':
-                        currency = 'kr./KWH'
-                    else:
-                        currency = '€/KWH'
-                    return currency
+    @staticmethod
+    def get_currency(data):
+        if data.get('country') == 'DK' or data.get('currency') == 'DKK':
+            currency = 'kr./KWH'
+        else:
+            currency = '€/KWH'
+        return currency
 
     def update_spot_price(self, price_code):
         current_time = self.hour_rounder(datetime.now().replace(microsecond=0)).isoformat() + 'Z'
@@ -59,8 +49,11 @@ class Barry:
             price_code, last_hour_date_time, current_time)
         response = requests.post('https://jsonrpc.barry.energy/json-rpc', headers=headers, data=data)
         json_res = response.json()
-        if json_res.get('result'):
-            return json_res['result'][0]['value']
+        result = json_res.get('result')
+        if result:
+            result = result[0]
+            value, currency = result['value'], self.get_currency(result)
+            return value, currency
 
     def update_total_price(self, mpid):
         current_time = self.hour_rounder(datetime.now().replace(microsecond=0)).isoformat() + 'Z'
@@ -74,9 +67,9 @@ class Barry:
             mpid, last_hour_date_time, current_time)
         response = requests.post('https://jsonrpc.barry.energy/json-rpc', headers=headers, data=data)
         json_res = response.json()
-        if json_res.get('result'):
-            result = json_res.get('result')[0]
-            value, currency = result
+        result = json_res.get('result')
+        if result:
+            value, currency = result['value'], self.get_currency(result)
             return value, currency
 
     def get_all_metering_points(self, check_token=False):
